# PySchoolBucks
Python wrapper for the MySchoolBucks Pay API

## Installation
    pip install PySchoolBucks

## Usage
```python
from msb import MsbPayAPI, APIServer

pay = MsbPayAPI('example-key', APIServer.PRODUCTION)

# TODO: Do stuff with the pay object
